@@ -2,7 +2,6 @@
 
 // helper function to check if row contains any of the expected types
 bool has_it(Rcpp::DataFrame df_xf, std::set<std::string> xf_nams, R_xlen_t row) {
-
   bool has_it = false;
 
   // names as vector and set. because set is ordered, we have to change the
@@ -51,40 +50,19 @@ bool has_it(Rcpp::DataFrame df_xf, std::set<std::string> xf_nams, R_xlen_t row)
 
 // [[Rcpp::export]]
 Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.cellformat?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "numFmtId",
-    "fontId",
-    "fillId",
-    "borderId",
-    "xfId",
-    "applyNumberFormat",
-    "applyFont",
-    "applyFill",
-    "applyBorder",
-    "applyAlignment",
-    "applyProtection",
-    "pivotButton",
-    "quotePrefix",
-    // child alignment
-    "horizontal",
-    "indent",
-    "justifyLastLine",
-    "readingOrder",
-    "relativeIndent",
-    "shrinkToFit",
-    "textRotation",
-    "vertical",
-    "wrapText",
-    // child extLst
-    "extLst",
-    // child protection
-    "hidden",
-    "locked"
-  };
+  std::set<std::string> nams{"numFmtId", "fontId", "fillId", "borderId", "xfId", "applyNumberFormat", "applyFont",
+                             "applyFill", "applyBorder", "applyAlignment", "applyProtection", "pivotButton",
+                             "quotePrefix",
+                             // child alignment
+                             "horizontal", "indent", "justifyLastLine", "readingOrder", "relativeIndent", "shrinkToFit",
+                             "textRotation", "vertical", "wrapText",
+                             // child extLst
+                             "extLst",
+                             // child protection
+                             "hidden", "locked"};
 
   R_xlen_t nn = std::distance(xml_doc_xf->begin(), xml_doc_xf->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -93,8 +71,7 @@ Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -103,7 +80,6 @@ Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
   auto itr = 0;
   for (auto xml_xf : xml_doc_xf->children("xf")) {
     for (auto attrs : xml_xf.attributes()) {
-
       std::string attr_name = attrs.name();
       std::string attr_value = attrs.value();
       auto find_res = nams.find(attr_name);
@@ -122,12 +98,10 @@ Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
     // <extLst ...>
     // <protection ...>
     for (auto cld : xml_xf.children()) {
-
       std::string cld_name = cld.name();
 
       // check known names
-      if (cld_name ==  "alignment" || cld_name == "extLst" || cld_name == "protection") {
-
+      if (cld_name == "alignment" || cld_name == "extLst" || cld_name == "protection") {
         if (cld_name == "extLst") {
           R_xlen_t mtc = std::distance(nams.begin(), nams.find(cld_name));
           uint32_t pugi_format_flags = pugi::format_raw;
@@ -153,7 +127,7 @@ Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
         Rcpp::warning("%s: not valid for xf in openxml 2.8.1", cld_name);
       }
 
-    } // end aligment, extLst, protection
+    }  // end aligment, extLst, protection
 
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
@@ -169,10 +143,8 @@ Rcpp::DataFrame read_xf(XPtrXML xml_doc_xf) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_xf(Rcpp::DataFrame df_xf) {
-
   R_xlen_t n = static_cast<R_xlen_t>(df_xf.nrow());
   R_xlen_t k = static_cast<R_xlen_t>(df_xf.ncol());
   Rcpp::CharacterVector z(n);
@@ -181,42 +153,17 @@ Rcpp::CharacterVector write_xf(Rcpp::DataFrame df_xf) {
 
   std::vector<std::string> attrnams = df_xf.names();
 
-  std::set<std::string> xf_nams = {
-    "numFmtId",
-    "fontId",
-    "fillId",
-    "borderId",
-    "xfId",
-    "applyFont",
-    "applyFill",
-    "applyBorder",
-    "applyAlignment",
-    "applyNumberFormat",
-    "applyProtection",
-    "pivotButton",
-    "quotePrefix"
-  };
+  std::set<std::string> xf_nams{"numFmtId",        "fontId",      "fillId",      "borderId",       "xfId",
+                                "applyFont",       "applyFill",   "applyBorder", "applyAlignment", "applyNumberFormat",
+                                "applyProtection", "pivotButton", "quotePrefix"};
 
-  std::set<std::string> xf_nams_alignment = {
-    "horizontal",
-    "indent",
-    "justifyLastLine",
-    "readingOrder",
-    "relativeIndent",
-    "shrinkToFit",
-    "textRotation",
-    "vertical",
-    "wrapText"
-  };
+  std::set<std::string> xf_nams_alignment{"horizontal",   "indent",         "justifyLastLine",
+                                          "readingOrder", "relativeIndent", "shrinkToFit",
+                                          "textRotation", "vertical",       "wrapText"};
 
-  std::set<std::string> xf_nams_extLst = {
-    "extLst"
-  };
+  std::set<std::string> xf_nams_extLst{"extLst"};
 
-  std::set<std::string> xf_nams_protection = {
-    "hidden",
-    "locked"
-  };
+  std::set<std::string> xf_nams_protection{"hidden", "locked"};
 
   for (R_xlen_t i = 0; i < n; ++i) {
     pugi::xml_document doc;
@@ -248,7 +195,6 @@ Rcpp::CharacterVector write_xf(Rcpp::DataFrame df_xf) {
     }
 
     for (R_xlen_t j = 0; j < k; ++j) {
-
       std::string attrnam = attrnams[static_cast<size_t>(j)];
 
       // not all missing in match: ergo they are
@@ -305,7 +251,6 @@ Rcpp::CharacterVector write_xf(Rcpp::DataFrame df_xf) {
           xf_protection.append_attribute(attrnam.c_str()) = val_strl.c_str();
         }
       }
-
     }
 
     std::ostringstream oss;
@@ -317,31 +262,14 @@ Rcpp::CharacterVector write_xf(Rcpp::DataFrame df_xf) {
   return z;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_font(XPtrXML xml_doc_font) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.font?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "b",
-    "charset",
-    "color",
-    "condense",
-    "extend",
-    "family",
-    "i",
-    "name",
-    "outline",
-    // TODO might contain child <localName ...>
-    "scheme",
-    "shadow",
-    "strike",
-    "sz",
-    "u",
-    "vertAlign"
-  };
+  std::set<std::string> nams{"b", "charset", "color", "condense", "extend", "family", "i", "name", "outline",
+                             // TODO might contain child <localName ...>
+                             "scheme", "shadow", "strike", "sz", "u", "vertAlign"};
 
   R_xlen_t nn = std::distance(xml_doc_font->begin(), xml_doc_font->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -351,8 +279,7 @@ Rcpp::DataFrame read_font(XPtrXML xml_doc_font) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -360,9 +287,7 @@ Rcpp::DataFrame read_font(XPtrXML xml_doc_font) {
   // <xf ...>
   auto itr = 0;
   for (auto xml_font : xml_doc_font->children("font")) {
-
     for (auto cld : xml_font.children()) {
-
       std::string name = cld.name();
       std::string value = cld.value();
       auto find_res = nams.find(name);
@@ -379,7 +304,7 @@ Rcpp::DataFrame read_font(XPtrXML xml_doc_font) {
         Rcpp::as<Rcpp::CharacterVector>(df[mtc])[itr] = oss.str();
       }
 
-    } // end aligment, extLst, protection
+    }  // end aligment, extLst, protection
 
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
@@ -395,10 +320,8 @@ Rcpp::DataFrame read_font(XPtrXML xml_doc_font) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_font(Rcpp::DataFrame df_font) {
-
   auto n = df_font.nrow();
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
@@ -409,14 +332,11 @@ Rcpp::CharacterVector write_font(Rcpp::DataFrame df_font) {
 
     pugi::xml_node font = doc.append_child("font");
 
-
     for (auto j = 0; j < df_font.ncol(); ++j) {
-
       Rcpp::CharacterVector cv_s = "";
       cv_s = Rcpp::as<Rcpp::CharacterVector>(df_font[j])[i];
 
       if (cv_s[0] != "") {
-
         std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
         pugi::xml_document font_node;
@@ -424,9 +344,7 @@ Rcpp::CharacterVector write_font(Rcpp::DataFrame df_font) {
         if (!result) Rcpp::stop("loading font node fail: %s", cv_s);
 
         font.append_copy(font_node.first_child());
-
       }
-
     }
 
     std::ostringstream oss;
@@ -438,17 +356,12 @@ Rcpp::CharacterVector write_font(Rcpp::DataFrame df_font) {
   return z;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_numfmt(XPtrXML xml_doc_numfmt) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.numberingformat?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "formatCode",
-    "numFmtId"
-  };
+  std::set<std::string> nams{"formatCode", "numFmtId"};
 
   R_xlen_t nn = std::distance(xml_doc_numfmt->begin(), xml_doc_numfmt->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -457,8 +370,7 @@ Rcpp::DataFrame read_numfmt(XPtrXML xml_doc_numfmt) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -467,7 +379,6 @@ Rcpp::DataFrame read_numfmt(XPtrXML xml_doc_numfmt) {
   auto itr = 0;
   for (auto xml_numfmt : xml_doc_numfmt->children("numFmt")) {
     for (auto attrs : xml_numfmt.attributes()) {
-
       std::string attr_name = attrs.name();
       std::string attr_value = attrs.value();
       auto find_res = nams.find(attr_name);
@@ -495,10 +406,8 @@ Rcpp::DataFrame read_numfmt(XPtrXML xml_doc_numfmt) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_numfmt(Rcpp::DataFrame df_numfmt) {
-
   auto n = df_numfmt.nrow();
   Rcpp::CharacterVector z(n);
   uint32_t pugi_format_flags = pugi::format_raw | pugi::format_no_escapes;
@@ -532,15 +441,13 @@ Rcpp::CharacterVector write_numfmt(Rcpp::DataFrame df_numfmt) {
 
 // [[Rcpp::export]]
 Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.border?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nam_attrs {"diagonalDown", "diagonalUp", "outline"};
+  std::set<std::string> nam_attrs{"diagonalDown", "diagonalUp", "outline"};
 
-  std::set<std::string> nam_chlds {"start", "end",
-                                   "left", "right", "top", "bottom", "diagonal",
-                                   "vertical",  "horizontal"};
+  std::set<std::string> nam_chlds{"start",  "end",      "left",     "right",     "top",
+                                  "bottom", "diagonal", "vertical", "horizontal"};
 
   auto total_length = nam_attrs.size() + nam_chlds.size();
   std::vector<std::string> all_names(total_length);
@@ -548,9 +455,7 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
   std::copy(nam_attrs.begin(), nam_attrs.end(), all_names.begin());
   std::copy(nam_chlds.begin(), nam_chlds.end(), all_names.begin() + static_cast<R_xlen_t>(nam_attrs.size()));
 
-  std::set<std::string> nams(std::make_move_iterator(all_names.begin()),
-                             std::make_move_iterator(all_names.end()));
-
+  std::set<std::string> nams(std::make_move_iterator(all_names.begin()), std::make_move_iterator(all_names.end()));
 
   R_xlen_t nn = std::distance(xml_doc_border->begin(), xml_doc_border->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -560,8 +465,7 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -570,7 +474,6 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
   auto itr = 0;
   for (auto xml_border : xml_doc_border->children("border")) {
     for (auto attrs : xml_border.attributes()) {
-
       std::string attr_name = attrs.name();
       std::string attr_value = attrs.value();
       auto find_res = nams.find(attr_name);
@@ -585,7 +488,6 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
     }
 
     for (auto cld : xml_border.children()) {
-
       std::string cld_name = cld.name();
       auto find_res = nams.find(cld_name);
 
@@ -605,7 +507,6 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
     ++itr;
-
   }
 
   // 3. Create a data.frame
@@ -616,30 +517,25 @@ Rcpp::DataFrame read_border(XPtrXML xml_doc_border) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_border(Rcpp::DataFrame df_border) {
-
   R_xlen_t n = static_cast<R_xlen_t>(df_border.nrow());
   R_xlen_t k = static_cast<R_xlen_t>(df_border.ncol());
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
   uint32_t pugi_format_flags = pugi::format_raw | pugi::format_no_escapes;
 
-
   // openxml 2.8.1
   std::vector<std::string> attrnams = df_border.names();
-  std::set<std::string> nam_attrs = {"diagonalDown", "diagonalUp", "outline"};
-  std::set<std::string> nam_chlds = {"bottom", "diagonal", "end", "horizontal",
-                                     "left", "right", "start", "top",
-                                     "vertical"};
+  std::set<std::string> nam_attrs{"diagonalDown", "diagonalUp", "outline"};
+  std::set<std::string> nam_chlds{"bottom", "diagonal", "end", "horizontal", "left",
+                                  "right",  "start",    "top", "vertical"};
 
   for (R_xlen_t i = 0; i < n; ++i) {
     pugi::xml_document doc;
     pugi::xml_node border = doc.append_child("border");
 
     for (R_xlen_t j = 0; j < k; ++j) {
-
       std::string attr_j = attrnams[static_cast<size_t>(j)];
 
       // mimic which
@@ -673,7 +569,6 @@ Rcpp::CharacterVector write_border(Rcpp::DataFrame df_border) {
         cv_s = Rcpp::as<Rcpp::CharacterVector>(df_border[j])[i];
 
         if (cv_s[0] != "") {
-
           std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
           pugi::xml_document border_node;
@@ -681,7 +576,6 @@ Rcpp::CharacterVector write_border(Rcpp::DataFrame df_border) {
           if (!result) Rcpp::stop("loading border node fail: %s", cv_s);
 
           border.append_copy(border_node.first_child());
-
         }
       }
 
@@ -697,17 +591,12 @@ Rcpp::CharacterVector write_border(Rcpp::DataFrame df_border) {
   return z;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_fill(XPtrXML xml_doc_fill) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.font?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "gradientFill",
-    "patternFill"
-  };
+  std::set<std::string> nams{"gradientFill", "patternFill"};
 
   R_xlen_t nn = std::distance(xml_doc_fill->begin(), xml_doc_fill->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -717,8 +606,7 @@ Rcpp::DataFrame read_fill(XPtrXML xml_doc_fill) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -726,9 +614,7 @@ Rcpp::DataFrame read_fill(XPtrXML xml_doc_fill) {
   // <xf ...>
   auto itr = 0;
   for (auto xml_fill : xml_doc_fill->children("fill")) {
-
     for (auto cld : xml_fill.children()) {
-
       std::string name = cld.name();
       auto find_res = nams.find(name);
 
@@ -744,7 +630,7 @@ Rcpp::DataFrame read_fill(XPtrXML xml_doc_fill) {
         Rcpp::as<Rcpp::CharacterVector>(df[mtc])[itr] = oss.str();
       }
 
-    } // end aligment, extLst, protection
+    }  // end aligment, extLst, protection
 
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
@@ -760,10 +646,8 @@ Rcpp::DataFrame read_fill(XPtrXML xml_doc_fill) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_fill(Rcpp::DataFrame df_fill) {
-
   auto n = df_fill.nrow();
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
@@ -774,14 +658,11 @@ Rcpp::CharacterVector write_fill(Rcpp::DataFrame df_fill) {
 
     pugi::xml_node fill = doc.append_child("fill");
 
-
     for (auto j = 0; j < df_fill.ncol(); ++j) {
-
       Rcpp::CharacterVector cv_s = "";
       cv_s = Rcpp::as<Rcpp::CharacterVector>(df_fill[j])[i];
 
       if (cv_s[0] != "") {
-
         std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
         pugi::xml_document font_node;
@@ -789,9 +670,7 @@ Rcpp::CharacterVector write_fill(Rcpp::DataFrame df_fill) {
         if (!result) Rcpp::stop("loading fill node fail: %s", cv_s);
 
         fill.append_copy(font_node.first_child());
-
       }
-
     }
 
     std::ostringstream oss;
@@ -803,17 +682,14 @@ Rcpp::CharacterVector write_fill(Rcpp::DataFrame df_fill) {
   return z;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.border?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nam_attrs {"builtinId", "customBuiltin", "hidden",
-                                   "iLevel", "name", "xfId", "xr:uid"};
+  std::set<std::string> nam_attrs{"builtinId", "customBuiltin", "hidden", "iLevel", "name", "xfId", "xr:uid"};
 
-  std::set<std::string> nam_chlds {"extLst"};
+  std::set<std::string> nam_chlds{"extLst"};
 
   auto total_length = nam_attrs.size() + nam_chlds.size();
   std::vector<std::string> all_names(total_length);
@@ -821,9 +697,7 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
   std::copy(nam_attrs.begin(), nam_attrs.end(), all_names.begin());
   std::copy(nam_chlds.begin(), nam_chlds.end(), all_names.begin() + static_cast<R_xlen_t>(nam_attrs.size()));
 
-  std::set<std::string> nams(std::make_move_iterator(all_names.begin()),
-                             std::make_move_iterator(all_names.end()));
-
+  std::set<std::string> nams(std::make_move_iterator(all_names.begin()), std::make_move_iterator(all_names.end()));
 
   R_xlen_t nn = std::distance(xml_doc_cellStyle->begin(), xml_doc_cellStyle->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -833,8 +707,7 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -843,7 +716,6 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
   auto itr = 0;
   for (auto xml_cellStyle : xml_doc_cellStyle->children("cellStyle")) {
     for (auto attrs : xml_cellStyle.attributes()) {
-
       std::string attr_name = attrs.name();
       std::string attr_value = attrs.value();
       auto find_res = nams.find(attr_name);
@@ -858,7 +730,6 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
     }
 
     for (auto cld : xml_cellStyle.children()) {
-
       std::string cld_name = cld.name();
       auto find_res = nams.find(cld_name);
 
@@ -878,7 +749,6 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
     ++itr;
-
   }
 
   // 3. Create a data.frame
@@ -889,28 +759,24 @@ Rcpp::DataFrame read_cellStyle(XPtrXML xml_doc_cellStyle) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_cellStyle(Rcpp::DataFrame df_cellstyle) {
-
   R_xlen_t n = static_cast<R_xlen_t>(df_cellstyle.nrow());
   R_xlen_t k = static_cast<R_xlen_t>(df_cellstyle.ncol());
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
   uint32_t pugi_format_flags = pugi::format_raw | pugi::format_no_escapes;
 
-
   // openxml 2.8.1
-  std::vector<std::string>  attrnams = df_cellstyle.names();
-  std::set<std::string> nam_attrs = {"builtinId", "customBuiltin", "hidden", "iLevel", "name", "xfId"};
-  std::set<std::string> nam_chlds = {"extLst"};
+  std::set<std::string> nam_attrs{"builtinId", "customBuiltin", "hidden", "iLevel", "name", "xfId"};
+  std::vector<std::string> attrnams = df_cellstyle.names();
+  std::set<std::string> nam_chlds{"extLst"};
 
   for (R_xlen_t i = 0; i < n; ++i) {
     pugi::xml_document doc;
     pugi::xml_node cellstyle = doc.append_child("cellStyle");
 
     for (R_xlen_t j = 0; j < k; ++j) {
-
       std::string attr_j = attrnams[static_cast<size_t>(j)];
 
       // mimic which
@@ -944,7 +810,6 @@ Rcpp::CharacterVector write_cellStyle(Rcpp::DataFrame df_cellstyle) {
         cv_s = Rcpp::as<Rcpp::CharacterVector>(df_cellstyle[j])[i];
 
         if (cv_s[0] != "") {
-
           std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
           pugi::xml_document border_node;
@@ -952,7 +817,6 @@ Rcpp::CharacterVector write_cellStyle(Rcpp::DataFrame df_cellstyle) {
           if (!result) Rcpp::stop("loading cellStyle node fail: %s", cv_s);
 
           cellstyle.append_copy(border_node.first_child());
-
         }
       }
 
@@ -968,16 +832,14 @@ Rcpp::CharacterVector write_cellStyle(Rcpp::DataFrame df_cellstyle) {
   return z;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.border?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nam_attrs {"count", "name", "pivot", "table", "xr9:uid"};
+  std::set<std::string> nam_attrs{"count", "name", "pivot", "table", "xr9:uid"};
 
-  std::set<std::string> nam_chlds {"tableStyleElement"};
+  std::set<std::string> nam_chlds{"tableStyleElement"};
 
   auto total_length = nam_attrs.size() + nam_chlds.size();
   std::vector<std::string> all_names(total_length);
@@ -985,9 +847,7 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
   std::copy(nam_attrs.begin(), nam_attrs.end(), all_names.begin());
   std::copy(nam_chlds.begin(), nam_chlds.end(), all_names.begin() + static_cast<R_xlen_t>(nam_attrs.size()));
 
-  std::set<std::string> nams(std::make_move_iterator(all_names.begin()),
-                             std::make_move_iterator(all_names.end()));
-
+  std::set<std::string> nams(std::make_move_iterator(all_names.begin()), std::make_move_iterator(all_names.end()));
 
   R_xlen_t nn = std::distance(xml_doc_tableStyle->begin(), xml_doc_tableStyle->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -997,8 +857,7 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -1007,7 +866,6 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
   auto itr = 0;
   for (auto xml_tableStyle : xml_doc_tableStyle->children("tableStyle")) {
     for (auto attrs : xml_tableStyle.attributes()) {
-
       std::string attr_name = attrs.name();
       std::string attr_value = attrs.value();
       auto find_res = nams.find(attr_name);
@@ -1023,7 +881,6 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
 
     std::string cld_value;
     for (auto cld : xml_tableStyle.children()) {
-
       std::string cld_name = cld.name();
       auto find_res = nams.find(cld_name);
 
@@ -1043,7 +900,6 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
     ++itr;
-
   }
 
   // 3. Create a data.frame
@@ -1054,30 +910,25 @@ Rcpp::DataFrame read_tableStyle(XPtrXML xml_doc_tableStyle) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_tableStyle(Rcpp::DataFrame df_tablestyle) {
-
   R_xlen_t n = static_cast<R_xlen_t>(df_tablestyle.nrow());
   R_xlen_t k = static_cast<R_xlen_t>(df_tablestyle.ncol());
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
   uint32_t pugi_format_flags = pugi::format_raw | pugi::format_no_escapes;
 
-
   // openxml 2.8.1
   std::vector<std::string> attrnams = df_tablestyle.names();
 
-  std::set<std::string> nam_attrs = {"count", "name", "pivot", "table", "xr9:uid"};
-  std::set<std::string> nam_chlds = {"tableStyleElement"};
-
+  std::set<std::string> nam_attrs{"count", "name", "pivot", "table", "xr9:uid"};
+  std::set<std::string> nam_chlds{"tableStyleElement"};
 
   for (R_xlen_t i = 0; i < n; ++i) {
     pugi::xml_document doc;
     pugi::xml_node tablestyle = doc.append_child("tableStyle");
 
     for (R_xlen_t j = 0; j < k; ++j) {
-
       std::string attr_j = attrnams[static_cast<size_t>(j)];
 
       // mimic which
@@ -1111,16 +962,14 @@ Rcpp::CharacterVector write_tableStyle(Rcpp::DataFrame df_tablestyle) {
         cv_s = Rcpp::as<Rcpp::CharacterVector>(df_tablestyle[j])[i];
 
         if (cv_s[0] != "") {
-
           std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
           pugi::xml_document tableStyleElement;
           pugi::xml_parse_result result = tableStyleElement.load_string(font_i.c_str(), pugi_parse_flags);
           if (!result) Rcpp::stop("loading df_tablestyle node fail: %s", cv_s);
 
-          for (auto chld: tableStyleElement.children())
+          for (auto chld : tableStyleElement.children())
             tablestyle.append_copy(chld);
-
         }
       }
 
@@ -1136,23 +985,12 @@ Rcpp::CharacterVector write_tableStyle(Rcpp::DataFrame df_tablestyle) {
   return z;
 }
 
-
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_dxf(XPtrXML xml_doc_dxf) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.font?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "alignment",
-    "border",
-    "extLst",
-    "fill",
-    "font",
-    "numFmt",
-    "protection"
-  };
+  std::set<std::string> nams{"alignment", "border", "extLst", "fill", "font", "numFmt", "protection"};
 
   R_xlen_t nn = std::distance(xml_doc_dxf->begin(), xml_doc_dxf->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -1162,8 +1000,7 @@ Rcpp::DataFrame read_dxf(XPtrXML xml_doc_dxf) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -1171,9 +1008,7 @@ Rcpp::DataFrame read_dxf(XPtrXML xml_doc_dxf) {
   // <xf ...>
   auto itr = 0;
   for (auto xml_dxf : xml_doc_dxf->children("dxf")) {
-
     for (auto cld : xml_dxf.children()) {
-
       std::string name = cld.name();
       auto find_res = nams.find(name);
 
@@ -1189,7 +1024,7 @@ Rcpp::DataFrame read_dxf(XPtrXML xml_doc_dxf) {
         Rcpp::as<Rcpp::CharacterVector>(df[mtc])[itr] = value;
       }
 
-    } // end aligment, extLst, protection
+    }  // end aligment, extLst, protection
 
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
@@ -1205,10 +1040,8 @@ Rcpp::DataFrame read_dxf(XPtrXML xml_doc_dxf) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_dxf(Rcpp::DataFrame df_dxf) {
-
   auto n = df_dxf.nrow();
   Rcpp::CharacterVector z(n);
   uint32_t pugi_parse_flags = pugi::parse_cdata | pugi::parse_wconv_attribute | pugi::parse_ws_pcdata | pugi::parse_eol;
@@ -1219,14 +1052,11 @@ Rcpp::CharacterVector write_dxf(Rcpp::DataFrame df_dxf) {
 
     pugi::xml_node dxf = doc.append_child("dxf");
 
-
     for (auto j = 0; j < df_dxf.ncol(); ++j) {
-
       Rcpp::CharacterVector cv_s = "";
       cv_s = Rcpp::as<Rcpp::CharacterVector>(df_dxf[j])[i];
 
       if (cv_s[0] != "") {
-
         std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
         pugi::xml_document font_node;
@@ -1234,9 +1064,7 @@ Rcpp::CharacterVector write_dxf(Rcpp::DataFrame df_dxf) {
         if (!result) Rcpp::stop("loading dxf node fail: %s", cv_s);
 
         dxf.append_copy(font_node.first_child());
-
       }
-
     }
 
     std::ostringstream oss;
@@ -1248,18 +1076,12 @@ Rcpp::CharacterVector write_dxf(Rcpp::DataFrame df_dxf) {
   return z;
 }
 
-
-
 // [[Rcpp::export]]
 Rcpp::DataFrame read_colors(XPtrXML xml_doc_colors) {
-
   // https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.colors?view=openxml-2.8.1
 
   // openxml 2.8.1
-  std::set<std::string> nams {
-    "indexedColors",
-    "mruColors"
-  };
+  std::set<std::string> nams{"indexedColors", "mruColors"};
 
   R_xlen_t nn = std::distance(xml_doc_colors->begin(), xml_doc_colors->end());
   R_xlen_t kk = static_cast<R_xlen_t>(nams.size());
@@ -1269,8 +1091,7 @@ Rcpp::DataFrame read_colors(XPtrXML xml_doc_colors) {
 
   // 1. create the list
   Rcpp::List df(kk);
-  for (R_xlen_t i = 0; i < kk; ++i)
-  {
+  for (R_xlen_t i = 0; i < kk; ++i) {
     SET_VECTOR_ELT(df, i, Rcpp::CharacterVector(Rcpp::no_init(nn)));
   }
 
@@ -1278,9 +1099,7 @@ Rcpp::DataFrame read_colors(XPtrXML xml_doc_colors) {
   // <xf ...>
   auto itr = 0;
   for (auto xml_color : xml_doc_colors->children("colors")) {
-
     for (auto cld : xml_color.children()) {
-
       std::string name = cld.name();
       auto find_res = nams.find(name);
 
@@ -1296,7 +1115,7 @@ Rcpp::DataFrame read_colors(XPtrXML xml_doc_colors) {
         Rcpp::as<Rcpp::CharacterVector>(df[mtc])[itr] = cld_value;
       }
 
-    } // end aligment, extLst, protection
+    }  // end aligment, extLst, protection
 
     // rownames as character vectors matching to <c s= ...>
     rvec[itr] = std::to_string(itr);
@@ -1312,10 +1131,8 @@ Rcpp::DataFrame read_colors(XPtrXML xml_doc_colors) {
   return df;
 }
 
-
 // [[Rcpp::export]]
 Rcpp::CharacterVector write_colors(Rcpp::DataFrame df_colors) {
-
   R_xlen_t n = static_cast<R_xlen_t>(df_colors.nrow());
   R_xlen_t k = static_cast<R_xlen_t>(df_colors.ncol());
   Rcpp::CharacterVector z(n);
@@ -1327,14 +1144,11 @@ Rcpp::CharacterVector write_colors(Rcpp::DataFrame df_colors) {
 
     pugi::xml_node color = doc.append_child("colors");
 
-
     for (R_xlen_t j = 0; j < k; ++j) {
-
       Rcpp::CharacterVector cv_s = "";
       cv_s = Rcpp::as<Rcpp::CharacterVector>(df_colors[j])[i];
 
       if (cv_s[0] != "") {
-
         std::string font_i = Rcpp::as<std::string>(cv_s[0]);
 
         pugi::xml_document font_node;
@@ -1342,9 +1156,7 @@ Rcpp::CharacterVector write_colors(Rcpp::DataFrame df_colors) {
         if (!result) Rcpp::stop("loading color node fail: %s", cv_s);
 
         color.append_copy(font_node.first_child());
-
       }
-
     }
 
     std::ostringstream oss;
