@@ -257,7 +257,7 @@ test_that("test add_cell_style()", {
   expect_equal(exp, got)
 
   ###
-  exp <- "<xf applyAlignment=\"1\" applyBorder=\"1\" applyFill=\"1\" applyFont=\"1\" applyNumberFormat=\"1\" applyProtection=\"1\" borderId=\"1\" fillId=\"1\" fontId=\"1\" numFmtId=\"1\" pivotButton=\"0\" quotePrefix=\"0\" xfId=\"1\"><alignment horizontal=\"1\" indent=\"1\" justifyLastLine=\"1\" readingOrder=\"1\" relativeIndent=\"1\" shrinkToFit=\"1\" textRotation=\"1\" vertical=\"1\" wrapText=\"1\"/><protection hidden=\"1\" locked=\"1\"/><extLst><ext><foo/></ext></extLst></xf>"
+  exp <- "<xf applyAlignment=\"1\" applyBorder=\"1\" applyFill=\"1\" applyFont=\"1\" applyNumberFormat=\"1\" applyProtection=\"1\" borderId=\"1\" fillId=\"1\" fontId=\"1\" numFmtId=\"1\" pivotButton=\"0\" quotePrefix=\"0\" xfId=\"1\"><alignment horizontal=\"left\" indent=\"1\" justifyLastLine=\"1\" readingOrder=\"1\" relativeIndent=\"1\" shrinkToFit=\"1\" textRotation=\"1\" vertical=\"top\" wrapText=\"1\"/><protection hidden=\"1\" locked=\"1\"/><extLst><ext><foo/></ext></extLst></xf>"
   got <- create_cell_style(
     borderId = "1",
     fillId = "1",
@@ -266,14 +266,14 @@ test_that("test add_cell_style()", {
     pivotButton = "0",
     quotePrefix = "0",
     xfId = "1",
-    horizontal = "1",
+    horizontal = "left",
     indent = "1",
     justifyLastLine = "1",
     readingOrder = "1",
     relativeIndent = "1",
     shrinkToFit = "1",
     textRotation = "1",
-    vertical = "1",
+    vertical = "top",
     wrapText = "1",
     extLst = "<extLst><ext><foo/></ext></extLst>",
     hidden = "1",
